@@ -1,4 +1,5 @@
 from requests_html import HTMLSession
+
 from .html import HTML
 
 
@@ -28,11 +29,12 @@ class BotCrawlerPlugin:
     def javascript_enabled(self, enable: bool) -> None:
         self._javascript_enabled = enable
 
-    def request(self, url: str):
+    def request(self, url: str, wait_time: int = 0):
         """Executes a request to the given URL
 
         Args:
             url (str): The desired URL.
+            wait_time (int): The number of milliseconds to wait after initial render.
 
         Returns:
             HTML: an HTML object which can be used to parse elements.
@@ -40,7 +42,7 @@ class BotCrawlerPlugin:
         """
         response = self.session.get(url)
         if self.javascript_enabled:
-            response.html.render()
+            response.html.render(sleep=wait_time/1000)
         return HTML(response.html, self.javascript_enabled)
 
     def request_as_string(self, url: str) -> str:
